@@ -1,5 +1,6 @@
 from publicsuffix import PublicSuffixList
 from schoolbus.data import UNIVERSITY_DOMAINS
+from schoolbus.research_orgs import RESEARCH_ORG_DOMAINS
 
 _psl = PublicSuffixList()
 
@@ -13,6 +14,7 @@ ACADEMIC_TLDS = {
     'ac.fj': True,
     'ac.id': True,
     'ac.il': True,
+    'ac.in': True,
     'ac.ir': True,
     'ac.jp': True,
     'ac.ke': True,
@@ -69,6 +71,7 @@ ACADEMIC_TLDS = {
     'edu.hk': True,
     'edu.hn': True,
     'edu.ht': True,
+    'edu.in': True,
     'edu.iq': True,
     'edu.jm': True,
     'edu.jo': True,
@@ -132,7 +135,7 @@ BLACKLIST_TLDS = {
 __all__ = ('school_names', 'is_academic')
 
 def _get_root_domain(email):
-    _, domain = email.split('@')
+    _, domain = email.rsplit('@', 1)
     root_domain = _psl.get_public_suffix(domain)
     return root_domain
 
@@ -160,7 +163,10 @@ def school_names(email):
     root_domain = _get_root_domain(email)
     if root_domain in BLACKLIST_TLDS:
         return []
-    return UNIVERSITY_DOMAINS.get(root_domain, [])
+    names = UNIVERSITY_DOMAINS.get(root_domain, [])
+    if names:
+        return names
+    return RESEARCH_ORG_DOMAINS.get(root_domain, [])
 
 def is_academic(email):
     """
@@ -188,7 +194,10 @@ def is_academic(email):
     root_domain = _get_root_domain(email)
     if root_domain in BLACKLIST_TLDS:
         return False
-    _, tld = root_domain.split('.', 1)
+    parts = root_domain.split('.', 1)
+    if len(parts) != 2:
+        return False
+    _, tld = parts
     if tld in ACADEMIC_TLDS:
         return True
     return len(school_names(email)) > 0
