@@ -7,6 +7,7 @@ RESEARCH_ORG_DOMAINS = {
     'erasmusmc.nl': [u'Erasmus University Medical Center'],
     'ncbs.res.in': [u'National Centre for Biological Sciences'],
     'bccrc.ca': [u'BC Cancer Research Centre'],
-    'mpimf-heidelberg.mpg.de': [u'Max Planck Institute for Medical Research Heidelberg, Germany'],
+    'mpimf-heidelberg.mpg.de': [u'Max Planck Institute for Medical Research'],
+    'mpi-muenster.mpg.de': [u'Max Planck Institute for Molecular Biomedicine'],
     'dkfz-heidelberg.de': [u'German Cancer Research Center'],
 }
